#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2021/11/10 4:03 PM
# @File    : empirical_func.py
# @Software: PyCharm


import matplotlib.ticker as mtick
import matplotlib.pyplot as plt
import matplotlib.dates as mdates
import matplotlib
from empirical_func import *

file_dir = ''
times = ['2020-03-03 10:00',
         '2020-12-16 14:00',
         '2021-03-17 14:00',
         '2021-09-22 14:00']

time_file = {'2020-03-03 10:00': 'SPY_20200302-20200304',
             '2020-12-16 14:00': 'SPY_20201214-20201217',
             '2021-03-17 14:00': 'SPY_20210315-20210318',
             '2021-09-22 14:00': 'SPY_20210920-20210923'}

keywords = ['Return', 'Dollar_Volume']
discard = 0

fig = plt.figure(figsize=(10, 7))
fig.autofmt_xdate(ha='center')

xfmt = mdates.DateFormatter('%H:%M')

for i in range(len(times)):
    time = times[i]
    # print(time)
    file = file_dir + time_file[time] + '.csv'
    data = transform_data(file)
    fs = 15
    font = {'size': fs, 'family': 'Times'}
    matplotlib.rc('font', **font)
    kn = 30
    t1, t2 = get_times(data, time, discard, kn)
    array1, array2 = get_arrays(data, time, keywords[0], discard, kn)
    ax1 = plt.subplot(2, 2, i + 1)
    xfmt = mdates.DateFormatter('%H:%M')
    ax1.xaxis.set_major_formatter(xfmt)
    timep = datetime.strptime(time, '%Y-%m-%d %H:%M')
    ax1.set_title(datetime.strftime(timep, '%B %d, %Y'), fontsize=fs)
    y_mean = 0.5 * array1.mean() + 0.5 * array2.mean()
    ax1.set_ylim((-.006, .007))
    # print(array1.max() - array1.min(), array2.max() - array2.min())
    for tick in ax1.get_xticklabels():
        tick.set_rotation(45)

    lns1 = ax1.plot(t1, array1, 'k-', label=keywords[0], zorder=2)
    ax1.plot(t2, array2, 'k-', zorder=2)
    ax1.set_ylabel('Return', fontsize=fs)
    ax1.yaxis.set_major_formatter(mtick.FormatStrFormatter('%.3f'))

    ax2 = ax1.twinx()
    ax2.xaxis.set_major_formatter(xfmt)
    array1, array2 = get_arrays(data, time, keywords[1], discard, kn)
    lns2 = ax2.bar(t1, array1, width=6 * 10 ** (-4),
                   color='darkgray', label=keywords[1],
                   alpha=0.9, zorder=1)

    ax2.bar(t2, array2, width=6 * 10 ** (-4), color='darkgray', alpha=0.9, zorder=1)
    ax2.set_ylabel(keywords[1], fontsize=fs)
    ax2.set_ylim((0, 1500000000))
    ax2.ticklabel_format(style='sci', scilimits=(-1, 2), axis='y',
                         useLocale=True, useMathText=True)
    ax2.grid(False)
    timep = datetime.strptime(time, '%Y-%m-%d %H:%M')
    plt.axvline(timep, color='gray', linestyle='--')
    ax2.get_yaxis().set_visible(False)

    time_str = datetime.strftime(timep, '%Y%m%d')
    ax1.set_zorder(ax2.get_zorder() + 1)
    ax1.patch.set_visible(False)
    xfmt = mdates.DateFormatter('%H:%M')
    ax1.xaxis.set_major_formatter(xfmt)
    ax1.spines['top'].set_visible(False)
    ax1.spines['right'].set_visible(False)
    ax2.spines['top'].set_visible(False)
    ax2.spines['right'].set_visible(False)

plt.tight_layout()
plt.show()
