function output = ptvj(x1,x2,siglevel,MC)

kn_pre = length(x1);
% if length(x2)~=kn_pre
%     error('Window sizes should be the same.')
% end

% Compute Test Statistic
x = [x1; x2]; % all data
T = CvMKS(x,kn_pre); % CvM and KS statistics

% Permutation based decisions
Tperm = zeros(MC,2);
for mc = 1:MC
    xperm = x(randperm(length(x)));
    Tperm(mc,:) = CvMKS(xperm,kn_pre); % CvM and KS statistics
end
k = ceil(MC*(1-siglevel));
Tstar = [0,0]; ahat = [0,0];
for j=1:2
    tmp = mink(Tperm(:,j),k);
    Tstar(j) = tmp(k);
    Mplus = sum(Tperm(:,j) > Tstar(j));
    M0 = max(sum(Tperm(:,j) == Tstar(j)),1);
    ahat(j) = (MC * siglevel - Mplus) / M0;
end

output.T = T;
output.Tstar = Tstar;
output.ahat = ahat;
output.siglevel = siglevel;

% Rejection decision;
% CvM case
j = 1;
if T(j) > Tstar(j)
    output.CvMrejection = 1;
    output.CvMrandomized = 0;
elseif T(j) < Tstar(j)
    output.CvMrejection = 0;
    output.CvMrandomized = 0;
else
    output.CvMrejection = (rand(1)<ahat(j)); % reject with prob ahat
    output.CvMrandomized = 1;
end

% KS case
j = 2;
if T(j) > Tstar(j)
    output.KSrejection = 1;
    output.KSrandomized = 0;
elseif T(j) < Tstar(j)
    output.KSrejection = 0;
    output.KSrandomized = 0;
else
    output.KSrejection = (rand(1)<ahat(j)); % reject with prob ahat
    output.KSrandomized = 1;
end

%% this function compute CvM and KS statistics;
function output = CvMKS(x,kn_pre)
x1 = x(1:kn_pre);
x2 = x(kn_pre+1:end);
F1 = zeros(length(x),1);
F2 = zeros(length(x),1);
for i=1:length(x)
    F1(i) = mean(x1<=x(i));
    F2(i) = mean(x2<=x(i));
end
CvM = mean((F1-F2).^2); % CvM statistic;
KS = max(abs(F1-F2)); % KS statistic;
output = [CvM, KS];

